define((function () { 'use strict';

	function foo () {
		console.log( 'indented with tabs' );
	}

	return foo;

}));
